

SquareAperture
===============================

.. currentmodule:: poppy.poppy_core

.. autoclass:: SquareAperture
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~SquareAperture.size

   
   

   
   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: size

   
   

   
   
   